@@ -49,3 +49,6 @@ printf "%-8s%d\n" success $success
 printf "%-8s%d\n" failed $failed
 printf "%-8s%d\n" broken $broken
 printf "%-8s%d\n" total $total
+
+# exit with non-zero status if any failed tests
+test -z "$failed_tests"
